@@ -1,14 +1,14 @@
 #' Check input WKT
-#' 
-#' @import assertthat rgeos plyr
+#'
+#' @import rgeos plyr
 #' @importFrom stringr str_extract
 #' @export
 #' @param wkt A Well Known Text object
-#' @examples 
+#' @examples
 #' check_wkt('POLYGON((30.1 10.1, 10 20, 20 60, 60 60, 30.1 10.1))')
 #' check_wkt('POINT(30.1 10.1)')
 #' check_wkt('LINESTRING(3 4,10 50,20 25)')
-#' 
+#'
 #' # this passes this check, but isn't valid for GBIF
 #' wkt <- 'POLYGON((-178.59375 64.83258989321493,-165.9375 59.24622380205539,
 #' -147.3046875 59.065977905449806,-130.78125 51.04484764446178,-125.859375 36.70806354647625,
@@ -24,9 +24,9 @@
 
 check_wkt <- function(wkt=NULL){
   if(!is.null(wkt)){
-    assert_that(is.character(wkt))
+    stopifnot(is.character(wkt))
     y <- str_extract(wkt, "[A-Z]+")
-    if(!y %in% c('POINT','POLYGON','LINESTRING','LINEARRING')) 
+    if(!y %in% c('POINT','POLYGON','LINESTRING','LINEARRING'))
       stop("WKT must be of type POINT, POLYGON, LINESTRING, or LINEARRING")
 #     res <- try_default(readWKT(wkt), 'notvalid', quiet = TRUE)
     res <- tryCatch(readWKT(wkt), error = function(e) e)
@@ -35,4 +35,4 @@ check_wkt <- function(wkt=NULL){
       stop(res)
     wkt
   } else { NULL }
-}
\ No newline at end of file
+}
