@@ -41,3 +41,7 @@ test_that("returns the correct dimensions", {
   expect_equal(dim(aa), c(1,4))
   expect_equal(dim(cc), c(3,3))
 })
+
+test_that("name_usage fails correctly", {
+  expect_error(occ_get(key=766766824, config=timeout(0.001)))
+})
